---
title: Support
layout: page 
date: 2014-02-13
---

Support for Urubu is available via [GitHub Issues][issues].

Issues are not limited to bug reports or feature requests.  They are used for
discussions, questions and suggestions also. Just attach the appropriate label
to the issue.

[issues]: https://github.com/jandecaluwe/urubu/issues?labels=duplicate&state=open
